==> estateplat-common-1.2.4-20200918.005649-445-sources.jar: cn/gtmap/estateplat/model/server/core/BdcWsxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020-3-19
 * @description 完税信息表
 */
@Entity
@Table(name = "bdc_wsxx")
public class BdcWsxx{
    @Id
    @Column
    private String wsxxid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String htbh;//合同编号
    @Column
    private String pzhm;//税票号码
    @Column
    private String pzzg;//票证子规
    @Column
    private String swjg;//税务机关名称
    @Column
    private String swjggzxx;//税务机关代码
    @Column
    private String nsrmc;//纳税人名称
    @Column
    private String nsrsfzjhm;//纳税人身份证件号码
    @Column
    private String djzclxdm;//登记注册类型
    @Column
    private Double ybtsjenum;//应补退税金额数字
    @Column
    private String ybtsjechn;//应补退税金额中文
    @Column
    private String kpr;//开票人
    @Column
    private String n;//年
    @Column
    private String y;//月
    @Column
    private String r;//日
    @Column
    private String bz;//备注

    public String getWsxxid() {
        return wsxxid;
    }

    public void setWsxxid(String wsxxid) {
        this.wsxxid = wsxxid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getPzhm() {
        return pzhm;
    }

    public void setPzhm(String pzhm) {
        this.pzhm = pzhm;
    }

    public String getPzzg() {
        return pzzg;
    }

    public void setPzzg(String pzzg) {
        this.pzzg = pzzg;
    }

    public String getSwjg() {
        return swjg;
    }

    public void setSwjg(String swjg) {
        this.swjg = swjg;
    }

    public String getSwjggzxx() {
        return swjggzxx;
    }

    public void setSwjggzxx(String swjggzxx) {
        this.swjggzxx = swjggzxx;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getNsrsfzjhm() {
        return nsrsfzjhm;
    }

    public void setNsrsfzjhm(String nsrsfzjhm) {
        this.nsrsfzjhm = nsrsfzjhm;
    }

    public String getDjzclxdm() {
        return djzclxdm;
    }

    public void setDjzclxdm(String djzclxdm) {
        this.djzclxdm = djzclxdm;
    }

    public Double getYbtsjenum() {
        return ybtsjenum;
    }

    public void setYbtsjenum(Double ybtsjenum) {
        this.ybtsjenum = ybtsjenum;
    }

    public String getYbtsjechn() {
        return ybtsjechn;
    }

    public void setYbtsjechn(String ybtsjechn) {
        this.ybtsjechn = ybtsjechn;
    }

    public String getKpr() {
        return kpr;
    }

    public void setKpr(String kpr) {
        this.kpr = kpr;
    }

    public String getN() {
        return n;
    }

    public void setN(String n) {
        this.n = n;
    }

    public String getY() {
        return y;
    }

    public void setY(String y) {
        this.y = y;
    }

    public String getR() {
        return r;
    }

    public void setR(String r) {
        this.r = r;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.4-20250303.022112-1292-sources.jar: cn/gtmap/estateplat/model/server/core/BdcWsxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:zhengqi@gtmap.cn">zhengqi</a>
 * @version 1.0, 2020-3-19
 * @description 完税信息表
 */
@Entity
@Table(name = "bdc_wsxx")
public class BdcWsxx{
    @Id
    @Column
    private String wsxxid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String htbh;//合同编号
    @Column
    private String pzhm;//税票号码
    @Column
    private String pzzg;//票证子规
    @Column
    private String swjg;//税务机关名称
    @Column
    private String swjggzxx;//税务机关代码
    @Column
    private String nsrmc;//纳税人名称
    @Column
    private String nsrsfzjhm;//纳税人身份证件号码
    @Column
    private String djzclxdm;//登记注册类型
    @Column
    private Double ybtsjenum;//应补退税金额数字
    @Column
    private String ybtsjechn;//应补退税金额中文
    @Column
    private String kpr;//开票人
    @Column
    private String n;//年
    @Column
    private String y;//月
    @Column
    private String r;//日
    @Column
    private String bz;//备注
    @Column
    private String pzzldm;//凭证种类代码
    @Column
    private String djzclx;//登记注册类型
    @Column
    private String dz;//地址
    @Column
    private Double hjje;//合计金额
    @Column
    private String hjjedx;//合计金额大写

    public String getPzzldm() {
        return pzzldm;
    }

    public void setPzzldm(String pzzldm) {
        this.pzzldm = pzzldm;
    }

    public String getDjzclx() {
        return djzclx;
    }

    public void setDjzclx(String djzclx) {
        this.djzclx = djzclx;
    }

    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public Double getHjje() {
        return hjje;
    }

    public void setHjje(Double hjje) {
        this.hjje = hjje;
    }

    public String getHjjedx() {
        return hjjedx;
    }

    public void setHjjedx(String hjjedx) {
        this.hjjedx = hjjedx;
    }

    public String getWsxxid() {
        return wsxxid;
    }

    public void setWsxxid(String wsxxid) {
        this.wsxxid = wsxxid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getPzhm() {
        return pzhm;
    }

    public void setPzhm(String pzhm) {
        this.pzhm = pzhm;
    }

    public String getPzzg() {
        return pzzg;
    }

    public void setPzzg(String pzzg) {
        this.pzzg = pzzg;
    }

    public String getSwjg() {
        return swjg;
    }

    public void setSwjg(String swjg) {
        this.swjg = swjg;
    }

    public String getSwjggzxx() {
        return swjggzxx;
    }

    public void setSwjggzxx(String swjggzxx) {
        this.swjggzxx = swjggzxx;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getNsrsfzjhm() {
        return nsrsfzjhm;
    }

    public void setNsrsfzjhm(String nsrsfzjhm) {
        this.nsrsfzjhm = nsrsfzjhm;
    }

    public String getDjzclxdm() {
        return djzclxdm;
    }

    public void setDjzclxdm(String djzclxdm) {
        this.djzclxdm = djzclxdm;
    }

    public Double getYbtsjenum() {
        return ybtsjenum;
    }

    public void setYbtsjenum(Double ybtsjenum) {
        this.ybtsjenum = ybtsjenum;
    }

    public String getYbtsjechn() {
        return ybtsjechn;
    }

    public void setYbtsjechn(String ybtsjechn) {
        this.ybtsjechn = ybtsjechn;
    }

    public String getKpr() {
        return kpr;
    }

    public void setKpr(String kpr) {
        this.kpr = kpr;
    }

    public String getN() {
        return n;
    }

    public void setN(String n) {
        this.n = n;
    }

    public String getY() {
        return y;
    }

    public void setY(String y) {
        this.y = y;
    }

    public String getR() {
        return r;
    }

    public void setR(String r) {
        this.r = r;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
